import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { CloudFormationClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CloudFormationClient";
import { SignalResourceInput } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link SignalResourceCommand}.
 */
export interface SignalResourceCommandInput extends SignalResourceInput {
}
/**
 * @public
 *
 * The output of {@link SignalResourceCommand}.
 */
export interface SignalResourceCommandOutput extends __MetadataBearer {
}
declare const SignalResourceCommand_base: {
    new (input: SignalResourceCommandInput): import("@smithy/smithy-client").CommandImpl<SignalResourceCommandInput, SignalResourceCommandOutput, CloudFormationClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: SignalResourceCommandInput): import("@smithy/smithy-client").CommandImpl<SignalResourceCommandInput, SignalResourceCommandOutput, CloudFormationClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Sends a signal to the specified resource with a success or failure status. You can use the
 *    <code>SignalResource</code> operation in conjunction with a creation policy or update policy. CloudFormation doesn't
 *    proceed with a stack creation or update until resources receive the required number of signals or the timeout period
 *    is exceeded. The <code>SignalResource</code> operation is useful in cases where you want to send signals from
 *    anywhere other than an Amazon EC2 instance.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudFormationClient, SignalResourceCommand } from "@aws-sdk/client-cloudformation"; // ES Modules import
 * // const { CloudFormationClient, SignalResourceCommand } = require("@aws-sdk/client-cloudformation"); // CommonJS import
 * const client = new CloudFormationClient(config);
 * const input = { // SignalResourceInput
 *   StackName: "STRING_VALUE", // required
 *   LogicalResourceId: "STRING_VALUE", // required
 *   UniqueId: "STRING_VALUE", // required
 *   Status: "SUCCESS" || "FAILURE", // required
 * };
 * const command = new SignalResourceCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param SignalResourceCommandInput - {@link SignalResourceCommandInput}
 * @returns {@link SignalResourceCommandOutput}
 * @see {@link SignalResourceCommandInput} for command's `input` shape.
 * @see {@link SignalResourceCommandOutput} for command's `response` shape.
 * @see {@link CloudFormationClientResolvedConfig | config} for CloudFormationClient's `config` shape.
 *
 * @throws {@link CloudFormationServiceException}
 * <p>Base exception class for all service exceptions from CloudFormation service.</p>
 *
 * @public
 */
export declare class SignalResourceCommand extends SignalResourceCommand_base {
}
